Welcome to pythonICIKendallTau's documentation!
===============================================

.. include:: ../README.rst

Documentation index:
====================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   guide
   api
   tutorial



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
